@@ -30,14 +30,13 @@ try:
 except ImportError:
     pass
 import displayio
-from displayio import Group
 import terminalio
 from bitmaptools import draw_line
 from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "0.11.0"
+__version__ = "0.11.1"
 __repo__ = "https://github.com/jposada202020/CircuitPython_uplot.git"
 
 
@@ -93,7 +92,7 @@ class Uplot(displayio.Group):
             print("Defaulting to y=0")
             y = 0
 
-        super().__init__(x=x, y=y, scale=1)
+        super().__init__(x=x, y=y, scale=scale)
 
         self._axesparams = "box"
 
